==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/he.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "בדרך כלל ניתן לפתור את הבעיה על ידי כך שנותנים ל- webserver הרשאות כניסה לתיקיית confg",
    "See %s" : "ניתן לראות %s",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "Following databases are supported: %s" : "מסדי הנתונים הבאים נתמכים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %s with a version higher than %s is required - available version %s." : "ספריה %s בגרסה גבוהה מ- %s נדרשת - גרסה זמינה %s.",
    "Library %s with a version lower than %s is required - available version %s." : "ספריה %s בגרסה נמוכה מ- %s נדרשת - גרסה זמינה %s.",
    "Following platforms are supported: %s" : "הפלטפורמות הבאות נתמכות: %s",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "today" : "היום",
    "yesterday" : "אתמול",
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים"],
    "last month" : "חודש שעבר",
    "last year" : "שנה שעברה",
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים"],
    "seconds ago" : "שניות",
    "File name is a reserved word" : "שם קובץ הנו מילה שמורה",
    "File name contains at least one invalid character" : "שם קובץ כולל לפחות תו אחד לא חוקי",
    "File name is too long" : "שם קובץ ארוך מדי",
    "Dot files are not allowed" : "קבצי Dot אינם מותרים",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "Help" : "עזרה",
    "Apps" : "יישומים",
    "Settings" : "הגדרות",
    "Log out" : "התנתק",
    "Users" : "משתמשים",
    "Unknown user" : "משתמש לא ידוע",
    "Sharing" : "שיתוף",
    "Tips & tricks" : "טיפים וטריקים",
    "__language_name__" : "עברית",
    "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
    "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
    "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
    "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin username." : "קביעת שם משתמש מנהל",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Can't create or write into the data directory %s" : "לא ניתן ליצור או לכתוב לתוך תיקיית הנתונים %s",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
    "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
    "Sharing %s failed, because the user %s does not exist" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו קיים",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו חבר בקבוצות ש- %s חבר ב-",
    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
    "Sharing %s failed, because the group %s does not exist" : "השיתוף %s נכשל, כיוון שהקבוצה %s אינה קיימת",
    "Sharing %s failed, because %s is not a member of the group %s" : "השיתוף %s נכשל, כיוון ש- %s אינו חבר בקבוצה %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
    "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
    "Share type %s is not valid for %s" : "שיתוף מסוג %s אינו תקף ל- %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
    "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "השיתוף %s נכשל, כיוון שההרשאות עלו על ההרשאות שניתנו ל- %s",
    "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "השיתוף %s נכשל, כיוון שבצד אחורי לשיתוף עבור %s לא ניתן היה לאתר את מקורו",
    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "%s shared »%s« with you" : "%s שיתף/שיתפה איתך את »%s«",
    "%s via %s" : "%s על בסיס %s",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "Su" : "א",
    "Mo" : "ב",
    "Tu" : "ג",
    "We" : "ד",
    "Th" : "ה",
    "Fr" : "ו",
    "Sa" : "ש",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "The username is already being used" : "השם משתמש כבר בשימוש",
    "User disabled" : "משתמש מנוטרל",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "היישום \"%s\" לא ניתן להתקנה כיוון שיחסי התלות הבאים אינם מתקיימים: %s",
    "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
    "Can't read file" : "לא ניתן לקרוא קובץ",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
    "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/he.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "בדרך כלל ניתן לפתור את הבעיה על ידי כך שנותנים ל- webserver הרשאות כניסה לתיקיית confg",
    "See %s" : "ניתן לראות %s",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "Following databases are supported: %s" : "מסדי הנתונים הבאים נתמכים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %s with a version higher than %s is required - available version %s." : "ספריה %s בגרסה גבוהה מ- %s נדרשת - גרסה זמינה %s.",
    "Library %s with a version lower than %s is required - available version %s." : "ספריה %s בגרסה נמוכה מ- %s נדרשת - גרסה זמינה %s.",
    "Following platforms are supported: %s" : "הפלטפורמות הבאות נתמכות: %s",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "today" : "היום",
    "yesterday" : "אתמול",
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
    "last month" : "חודש שעבר",
    "last year" : "שנה שעברה",
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים","לפני %n שנים","לפני %n שנים"],
    "seconds ago" : "שניות",
    "File name is a reserved word" : "שם קובץ הנו מילה שמורה",
    "File name contains at least one invalid character" : "שם קובץ כולל לפחות תו אחד לא חוקי",
    "File name is too long" : "שם קובץ ארוך מדי",
    "Dot files are not allowed" : "קבצי Dot אינם מותרים",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "__language_name__" : "עברית",
    "Help" : "עזרה",
    "Apps" : "יישומים",
    "Settings" : "הגדרות",
    "Log out" : "התנתק",
    "Users" : "משתמשים",
    "Unknown user" : "משתמש לא ידוע",
    "Sharing" : "שיתוף",
    "Tips & tricks" : "טיפים וטריקים",
    "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
    "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
    "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
    "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin username." : "קביעת שם משתמש מנהל",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Can't create or write into the data directory %s" : "לא ניתן ליצור או לכתוב לתוך תיקיית הנתונים %s",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
    "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
    "Sharing %s failed, because the user %s does not exist" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו קיים",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו חבר בקבוצות ש- %s חבר ב-",
    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
    "Sharing %s failed, because the group %s does not exist" : "השיתוף %s נכשל, כיוון שהקבוצה %s אינה קיימת",
    "Sharing %s failed, because %s is not a member of the group %s" : "השיתוף %s נכשל, כיוון ש- %s אינו חבר בקבוצה %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
    "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
    "Share type %s is not valid for %s" : "שיתוף מסוג %s אינו תקף ל- %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
    "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "השיתוף %s נכשל, כיוון שההרשאות עלו על ההרשאות שניתנו ל- %s",
    "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "השיתוף %s נכשל, כיוון שבצד אחורי לשיתוף עבור %s לא ניתן היה לאתר את מקורו",
    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "%s shared »%s« with you" : "%s שיתף/שיתפה איתך את »%s«",
    "%s via %s" : "%s על בסיס %s",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "Su" : "א",
    "Mo" : "ב",
    "Tu" : "ג",
    "We" : "ד",
    "Th" : "ה",
    "Fr" : "ו",
    "Sa" : "ש",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "The username is already being used" : "השם משתמש כבר בשימוש",
    "User disabled" : "משתמש מנוטרל",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "היישום \"%s\" לא ניתן להתקנה כיוון שיחסי התלות הבאים אינם מתקיימים: %s",
    "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
    "Can't read file" : "לא ניתן לקרוא קובץ",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
    "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
